`xotl.tools.string`:mod: - Common string operations
===================================================

.. automodule:: xotl.tools.string
   :members: cut_prefix, cut_any_prefix, cut_prefixes, cut_suffix,
             cut_any_suffix, cut_suffixes, error2str, make_a10z


.. autofunction:: slugify(value, replacement='-', invalid_chars='', valid_chars='', encoding=None)

.. function:: normalize_slug(value, replacement='-', invalid_chars='', valid_chars='', encoding=None)

   Deprecated alias of `slugify`:func:.
